@@ -206,3 +206,34 @@ class dyn_vec:
             self.point_rf.ob.keyframe_insert(data_path='location', frame=cur_frame)
             self.parent_rf.ob.keyframe_insert(data_path='scale', frame=cur_frame)
 
+class anim_text:
+    def __init__(self, name, data, label, fix_place, if_str, anim):
+        bpy.data.curves.new(type="FONT", name="Font Curve").body = "INIT"
+        font_obj = bpy.data.objects.new(name=name+'_text', object_data=bpy.data.curves["Font Curve"])
+        bpy.context.scene.collection.objects.link(font_obj)
+
+        if not(if_str):
+            def update(self):
+                text = bpy.data.objects[name+'_text']
+                cur_frame = bpy.context.scene.frame_current
+                
+                if np.any(cur_frame == anim.frames):
+                    ind = np.where(cur_frame == anim.frames)[0][0]
+                    text.data.body = ('{0:.'+str(fix_place)+'f}').format(data[ind]) + ' ' + label
+                    
+        else:
+            def update(self):
+                text = bpy.data.objects[name+'_text']
+                cur_frame = bpy.context.scene.frame_current
+                
+                if np.any(cur_frame == anim.frames):
+                    ind = np.where(cur_frame == anim.frames)[0][0]
+                    text.data.body = data[ind]
+
+        def register():
+            bpy.app.handlers.frame_change_post.append(update)
+
+        def unregister():
+            bpy.app.handlers.frame_change_post.remove(update)
+
+        register()
\ No newline at end of file
